#!/usr/bin/env python
import sys
import optparse
import logging

from PyQt4.QtCore import PYQT_VERSION_STR as VERSION

from PyQt4.uic.exceptions import NoSuchWidgetError

def previewUi(filename):
    from PyQt4 import QtGui
    from PyQt4.uic import Loader
    app = QtGui.QApplication([filename])
    widget = Loader.loadUi(filename)
    widget.show()
    return app.exec_()

optparser = optparse.OptionParser(usage = "%prog [options] <ui-file>",
                                  version = "%prog " + VERSION)
optparser.add_option("-p", "--preview", dest="preview",
                     action="store_true", default=False,
                     help="show a preview of the UI instead of generating code")
optparser.add_option("-o", "--output", dest="output_filename",
                     default="-", metavar="FILE",
                     help="write generated code to FILE")
optparser.add_option("-x", "--execute", dest="testcode",
                     action="store_true", default=False,
                     help="generate extra code to test and display the class")
optparser.add_option("-d", "--debug", dest="debug",
                     action="store_true", default=False,
                     help="show debug output")
optparser.add_option("-i", "--indent", dest="indentwidth",
                     action="store", type="int", default=4, metavar="X",
                     help="set indent width to X spaces (Default: 4)")

options, args = optparser.parse_args(sys.argv)

if len(args) < 2:
    print "Error: no input file specified"
    sys.exit(1)

if options.debug:
    logging.getLogger().setLevel(logging.DEBUG)

error = 1
try:
    if options.preview:
        error = previewUi(args[1])
    else:
        from PyQt4.uic import Compiler
        error = Compiler.generatePythonModule(args[1], options.output_filename,
                                               options.testcode, options.indentwidth)
except IOError, e:
    sys.stderr.write("Error: %s: \"%s\"\n" % (e.strerror, e.filename))

except SyntaxError, e:
    sys.stderr.write("Error in input file: %s\n" % (e,))

except NoSuchWidgetError, e:
    if e.args[0].startswith("Q3"):
        sys.stderr.write("Error: Q3Support widgets are not included in PyQt4.\n")
    else:
        sys.stderr.write(e)

except Exception, e:
    if logging.getLogger().level == logging.DEBUG:
        import traceback
        traceback.print_exception(*sys.exc_info())
    else:
        sys.stderr.write("""An unexpected error occurred.
Please send an error report to support@riverbankcomputing.co.uk and include the following data:
  * your version of PyQt4 (%s)
  * the UI file that caused this error
  * the debug output of pyuic4 (use the -d flag when calling pyuic4)
""" % (VERSION,))

sys.exit(error)
